@@ -1,6 +1,6 @@
 """Provides the interface to load configuration files."""
 import yaml
-from unimatrix.ext import etc
+from unimatrix import etc
 
 from .provider import get_requirement
 
