@@ -5,6 +5,7 @@ from marshmallow.exceptions import ValidationError
 
 from ioc.schema.exc import InvalidDeclaration
 from ioc.schema.adapters import SymbolDependencyAdapter
+from ioc.schema.adapters import FileDependencyAdapter
 from ioc.schema.adapters import LiteralDependencyAdapter
 from ioc.schema.adapters import NestedDependencyAdapter
 from ioc.schema.adapters import DependencyCollectionAdapter
@@ -43,6 +44,7 @@ class SchemaParser(object):
         adapters = [
             SymbolDependencyAdapter(),
             NestedDependencyAdapter(),
+            FileDependencyAdapter(),
             LiteralDependencyAdapter(),
             DependencyCollectionAdapter(),
         ]
